@@ -3,9 +3,7 @@ use strict;
 use warnings;
 package App::Spec::Pod;
 
-our $VERSION = '0.008_001'; # TRIAL VERSION
-
-use Text::Table;
+our $VERSION = 'v0.15.0'; # VERSION
 
 use Moo;
 
@@ -154,7 +152,6 @@ sub params2pod {
     my ($self, %args) = @_;
     my $params = $args{parameters};
     my @rows;
-    my $tb = Text::Table->new;
     for my $param (@$params) {
         my $required = $param->required ? '*' : '';
         my $summary = $param->summary;
@@ -166,17 +163,41 @@ sub params2pod {
             $multi = '[]';
         }
         my $flags = $self->spec->_param_flags_string($param);
-        push @rows, ["    " . $param->name, " " . $required, $multi, $summary . $flags];
+        my @lines = split m/\n/, $summary;
+        push @rows, ["    " . $param->name, " " . $required, $multi, ($lines[0] // '') . $flags];
+        push @rows, ["    " , " ", '', $_] for map {s/^ +//; $_ } @lines[1 .. $#lines];
     }
-    $tb->load(@rows);
-    return "$tb";
+    my $test = $self->simple_table(\@rows);
+    return $test;
+}
+
+sub simple_table {
+    my ($self, $rows) = @_;
+    my @widths;
+
+    for my $row (@$rows) {
+        for my $i (0 .. $#$row) {
+            my $col = $row->[ $i ];
+            $widths[ $i ] ||= 0;
+            if ( $widths[ $i ] < length $col) {
+                $widths[ $i ] = length $col;
+            }
+        }
+    }
+    my $format = join ' ', map { "%-" . ($_ || 0) . "s" } @widths;
+    my @lines;
+    for my $row (@$rows) {
+        my $string = sprintf "$format\n", map { $_ // '' } @$row;
+        push @lines, $string;
+    }
+    return join '', @lines;
+
 }
 
 sub options2pod {
     my ($self, %args) = @_;
     my $options = $args{options};
     my @rows;
-    my $tb = Text::Table->new;
     for my $opt (@$options) {
         my $name = $opt->name;
         my $aliases = $opt->aliases;
@@ -193,10 +214,12 @@ sub options2pod {
             length $_ > 1 ? "--$_" : "-$_"
         } ($name, @$aliases);
         my $flags = $self->spec->_param_flags_string($opt);
-        push @rows, ["    @names", " " . $required, $multi, $summary . $flags];
+        my @lines = split m/\n/, $summary;
+        push @rows, ["    @names", " " . $required, $multi, ($lines[0] // '') . $flags];
+        push @rows, ["    ", " " , '', $_ ] for map {s/^ +//; $_ } @lines[1 .. $#lines];
     }
-    $tb->load(@rows);
-    return "$tb";
+    my $test = $self->simple_table(\@rows);
+    return $test;
 }
 
 sub markup {
